@@ -589,16 +589,20 @@ class Citation extends \JTable
 	{
 		$stats = array();
 
-		for ($i=date("Y"), $n=1998; $i > $n; $i--)
+		$this->_db->setQuery("SELECT `year` FROM $this->_tbl WHERE `published`=1 AND `year` > 0 AND (`scope`='' OR `scope` IS NULL) ORDER BY `year` ASC LIMIT 1");
+		$year = intval($this->_db->loadResult());
+		$year = $year ? $year : gmdate("Y");
+
+		for ($i=date("Y"), $n=$year; $i > $n; $i--)
 		{
 			$stats[$i] = array();
 
 			// Not supported in PLG_GROUPS_CITATIONS or PLG_MEMBERS_CITATIONS
-			$this->_db->setQuery("SELECT COUNT(*) FROM $this->_tbl WHERE published=1 AND year=" . $this->_db->quote($i) . " AND affiliated=1 AND (scope IS NULL OR scope IS NULL)");
+			$this->_db->setQuery("SELECT COUNT(*) FROM $this->_tbl WHERE published=1 AND year=" . $this->_db->quote($i) . " AND affiliated=1 AND (scope='' OR scope IS NULL)");
 			$stats[$i]['affiliate'] = $this->_db->loadResult();
 
 			// Not supported in PLG_GROUPS_CITATIONS or PLG_MEMBERS_CITATIONS
-			$this->_db->setQuery("SELECT COUNT(*) FROM $this->_tbl WHERE published=1 AND year=" . $this->_db->quote($i) . " AND affiliated=0 AND (scope IS NULL OR scope IS NULL)");
+			$this->_db->setQuery("SELECT COUNT(*) FROM $this->_tbl WHERE published=1 AND year=" . $this->_db->quote($i) . " AND affiliated=0 AND (scope='' OR scope IS NULL)");
 			$stats[$i]['non-affiliate'] = $this->_db->loadResult();
 		}
 
