@@ -98,7 +98,7 @@ jQuery(document).ready(function($) {
 			if (dv_settings.serverside) {
 				$('.dv_header_select_all').each(function() {
 					var id = $(this).val();
-					if(dv.selected_cells[id]) {
+					if(dv.selected_cells && dv.selected_cells[id]) {
 						for (i=0; i<dv.selected_cells[id].length; i++) {
 							$('.' + id + ':checkbox[value="' + dv.selected_cells[id][i] + '"]').prop('checked', true);
 						}
@@ -533,10 +533,10 @@ jQuery(document).ready(function($) {
 		}
 
 		$(dv_table.fnGetNodes()).find('.' + id + ':checkbox:checked').each(function() {
-			url += $(this).val() + ',';
+			url += 'file:' + $(this).val() + '%0A%0B';
 		});
 
-		url = url.slice(0, (url.length-1));
+		url = url.slice(0, (url.length-6));
 
 		if (typeof pageTracker != 'undefined') {
 			pageTracker._trackEvent('Data viewer', 'Tools launch (multiple)', url);
