@@ -88,6 +88,11 @@ class Manage extends AdminController
 				'policy',
 				''
 			),
+			'state'     => Request::getState(
+				$this->_option . '.browse.state',
+				'state',
+				-1
+			),
 			'sort'       => Request::getState(
 				$this->_option . '.browse.sort',
 				'filter_order',
@@ -107,7 +112,7 @@ class Manage extends AdminController
 		$canDo = \Components\Groups\Helpers\Permissions::getActions('group');
 		if (!$canDo->get('core.admin'))
 		{
-			if ($this->view->filters['type'][0] == 'system' || $this->view->filters['type'][0] == "0" || $this->view->filters['type'][0] == NULL)
+			if ($this->view->filters['type'][0] == 'system' || $this->view->filters['type'][0] == "0" || $this->view->filters['type'][0] == null)
 			{
 				$this->view->filters['type'] = array('all');
 			}
@@ -123,6 +128,11 @@ class Manage extends AdminController
 			}
 		}
 
+		if ($this->view->filters['state'] >= 0)
+		{
+			$this->view->filters['published'] = $this->view->filters['state'];
+		}
+
 		// Get a record count
 		$this->view->total = Group::find($this->view->filters);
 
@@ -185,8 +195,6 @@ class Manage extends AdminController
 	{
 		Request::setVar('hidemainmenu', 1);
 
-		$this->view->setLayout('edit');
-
 		// Incoming
 		$id = Request::getVar('id', array());
 
@@ -197,25 +205,23 @@ class Manage extends AdminController
 		}
 
 		// determine task
-		$task = ($id == '') ? 'create' : 'edit';
+		$task = (!$id ? 'create' : 'edit');
 
-		$this->view->group = new Group();
-		$this->view->group->read($id);
+		$group = new Group();
+		$group->read($id);
 
-		// make sure we are organized
-		if (!$this->authorize($task, $this->view->group))
+		// Make sure we are authorized
+		if (!$this->authorize($task, $group))
 		{
-			return;
-		}
-
-		// Set any errors
-		foreach ($this->getErrors() as $error)
-		{
-			$this->view->setError($error);
+			App::abort(403, Lang::txt('JERROR_ALERTNOAUTHOR'));
 		}
 
 		// Output the HTML
-		$this->view->display();
+		$this->view
+			->setErrors($this->getErrors())
+			->setLayout('edit')
+			->set('group', $group)
+			->display();
 	}
 
 	/**
@@ -275,9 +281,10 @@ class Manage extends AdminController
 		}
 
 		$task = ($this->_task == 'edit') ? 'edit' : 'create';
+
 		if (!$this->authorize($task, $group))
 		{
-			return;
+			App::abort(403, Lang::txt('JERROR_ALERTNOAUTHOR'));
 		}
 
 		// Check for any missing info
@@ -293,17 +300,12 @@ class Manage extends AdminController
 		// Push back into edit mode if any errors
 		if ($this->getError())
 		{
-			$this->view->setLayout('edit');
-			$this->view->group = $group;
-
-			// Set any errors
-			if ($this->getError())
-			{
-				$this->view->setError($this->getError());
-			}
-
 			// Output the HTML
-			$this->view->display();
+			$this->view
+				->setErrors($this->getErrors())
+				->setLayout('edit')
+				->set('group', $group)
+				->display();
 			return;
 		}
 
@@ -327,17 +329,12 @@ class Manage extends AdminController
 		// Push back into edit mode if any errors
 		if ($this->getError())
 		{
-			$this->view->setLayout('edit');
-			$this->view->group = $group;
-
-			// Set any errors
-			if ($this->getError())
-			{
-				$this->view->setError($this->getError());
-			}
-
 			// Output the HTML
-			$this->view->display();
+			$this->view
+				->setErrors($this->getErrors())
+				->setLayout('edit')
+				->set('group', $group)
+				->display();
 			return;
 		}
 
@@ -409,7 +406,6 @@ class Manage extends AdminController
 			$version->store(false);
 		}
 
-
 		// Get plugins
 		Event::trigger('groups.onGroupAfterSave', array($before, $group));
 
@@ -430,10 +426,9 @@ class Manage extends AdminController
 		}
 
 		// Output messsage and redirect
-		App::redirect(
-			Route::url('index.php?option=' . $this->_option . '&controller=' . $this->_controller, false),
-			Lang::txt('COM_GROUPS_SAVED')
-		);
+		Notify::success(Lang::txt('COM_GROUPS_SAVED'));
+
+		$this->cancelTask();
 	}
 
 	/**
@@ -879,12 +874,8 @@ class Manage extends AdminController
 		// empty list?
 		if (empty($ids))
 		{
-			App::redirect(
-				Route::url('index.php?option=' . $this->_option . '&controller=' . $this->_controller, false),
-				Lang::txt('There are no eligible merge requests.'),
-				'warning'
-			);
-			return;
+			Notify::warning(Lang::txt('There are no eligible merge requests.'));
+			return $this->cancelTask();
 		}
 
 		// vars to hold results of pull
@@ -906,7 +897,10 @@ class Manage extends AdminController
 			// make sure its a super group
 			if (!$group->isSuperGroup())
 			{
-				$failed[] = array('group' => $group->get('cn'), 'message' => Lang::txt('COM_GROUPS_GITLAB_NOT_SUPER_GROUP'));
+				$failed[] = array(
+					'group'   => $group->get('cn'),
+					'message' => Lang::txt('COM_GROUPS_GITLAB_NOT_SUPER_GROUP')
+				);
 				continue;
 			}
 
@@ -918,7 +912,10 @@ class Manage extends AdminController
 			{
 				if (!Filesystem::makeDirectory($uploadPath))
 				{
-					$failed[] = array('group' => $group->get('cn'), 'message' => Lang::txt('COM_GROUPS_GITLAB_UPLOAD_PATH_DOESNT_EXIST'));
+					$failed[] = array(
+						'group'   => $group->get('cn'),
+						'message' => Lang::txt('COM_GROUPS_GITLAB_UPLOAD_PATH_DOESNT_EXIST')
+					);
 					continue;
 				}
 			}
@@ -945,7 +942,7 @@ class Manage extends AdminController
 			// this will run a "git pull --rebase origin master"
 			$output = shell_exec($cmd);
 
-			if (strpos($output, 'ineligble') === FALSE)
+			if (strpos($output, 'ineligble') === false)
 			{
 				$museCmd = 'migrate';
 				$cmd = "cd {$uploadPath} && ";
@@ -963,21 +960,28 @@ class Manage extends AdminController
 			if (preg_match("/Updating the repository.../uis", $output))
 			{
 				// add success message
-				$success[] = array('group' => $group->get('cn'), 'message' => $output);
+				$success[] = array(
+					'group'   => $group->get('cn'),
+					'message' => $output
+				);
 			}
 			else
 			{
 				// add failed message
-				$failed[] = array('group' => $group->get('cn'), 'message' => $output);
+				$failed[] = array(
+					'group'   => $group->get('cn'),
+					'message' => $output
+				);
 			}
 		}
 
 		// display view
-		$this->view->setLayout('merged');
-		$this->view->success = $success;
-		$this->view->failed  = $failed;
-		$this->view->config  = $this->config;
-		$this->view->display();
+		$this->view
+			->setLayout('merged')
+			->set('success', $success)
+			->set('failed', $failed)
+			->set('config', $this->config)
+			->display();
 	}
 
 	/**
@@ -990,6 +994,11 @@ class Manage extends AdminController
 		// Check for request forgeries
 		Request::checkToken();
 
+		if (!User::authorise('core.delete', $this->_option))
+		{
+			App::abort(403, Lang::txt('JERROR_ALERTNOAUTHOR'));
+		}
+
 		// Incoming
 		$ids = Request::getVar('id', array());
 
@@ -1074,9 +1083,7 @@ class Manage extends AdminController
 		}
 
 		// Redirect back to the groups page
-		App::redirect(
-			Route::url('index.php?option=' . $this->_option . '&controller=' . $this->_controller, false)
-		);
+		$this->cancelTask();
 	}
 
 	/**
@@ -1087,7 +1094,12 @@ class Manage extends AdminController
 	public function publishTask()
 	{
 		// Check for request forgeries
-		//Request::checkToken();
+		Request::checkToken(['get', 'post']);
+
+		if (!User::authorise('core.edit.state', $this->_option))
+		{
+			App::abort(403, Lang::txt('JERROR_ALERTNOAUTHOR'));
+		}
 
 		// Incoming
 		$ids = Request::getVar('id', array());
@@ -1098,6 +1110,8 @@ class Manage extends AdminController
 			$ids = array($ids);
 		}
 
+		$i = 0;
+
 		// Do we have any IDs?
 		if (!empty($ids))
 		{
@@ -1124,15 +1138,18 @@ class Manage extends AdminController
 					'action'    => 'group_published',
 					'comments'  => 'published by administrator'
 				));
+
+				$i++;
 			}
 
 			// Output messsage and redirect
-			Notify::success(Lang::txt('COM_GROUPS_PUBLISHED'));
+			if ($i)
+			{
+				Notify::success(Lang::txt('COM_GROUPS_SUCCESS_PUBLISHED', $i));
+			}
 		}
 
-		App::redirect(
-			Route::url('index.php?option=' . $this->_option . '&controller=' . $this->_controller, false)
-		);
+		$this->cancelTask();
 	}
 
 	/**
@@ -1143,7 +1160,12 @@ class Manage extends AdminController
 	public function unpublishTask()
 	{
 		// Check for request forgeries
-		//Request::checkToken();
+		Request::checkToken(['get', 'post']);
+
+		if (!User::authorise('core.edit.state', $this->_option))
+		{
+			App::abort(403, Lang::txt('JERROR_ALERTNOAUTHOR'));
+		}
 
 		// Incoming
 		$ids = Request::getVar('id', array());
@@ -1154,6 +1176,8 @@ class Manage extends AdminController
 			$ids = array($ids);
 		}
 
+		$i = 0;
+
 		// Do we have any IDs?
 		if (!empty($ids))
 		{
@@ -1180,15 +1204,84 @@ class Manage extends AdminController
 					'action'    => 'group_unpublished',
 					'comments'  => 'unpublished by administrator'
 				));
+
+				$i++;
 			}
 
 			// Output messsage
-			Notify::success(Lang::txt('COM_GROUPS_UNPUBLISHED'));
+			if ($i)
+			{
+				Notify::success(Lang::txt('COM_GROUPS_SUCCESS_UNPUBLISHED', $i));
+			}
 		}
 
-		App::redirect(
-			Route::url('index.php?option=' . $this->_option . '&controller=' . $this->_controller, false)
-		);
+		$this->cancelTask();
+	}
+
+	/**
+	 * Archive a group
+	 *
+	 * @return  void
+	 */
+	public function archiveTask()
+	{
+		// Check for request forgeries
+		Request::checkToken(['get', 'post']);
+
+		if (!User::authorise('core.edit.state', $this->_option))
+		{
+			App::abort(403, Lang::txt('JERROR_ALERTNOAUTHOR'));
+		}
+
+		// Incoming
+		$ids = Request::getVar('id', array());
+
+		// Get the single ID we're working with
+		if (!is_array($ids))
+		{
+			$ids = array($ids);
+		}
+
+		$i = 0;
+
+		// Do we have any IDs?
+		if (!empty($ids))
+		{
+			//foreach group id passed in
+			foreach ($ids as $id)
+			{
+				// Load the group page
+				$group = new Group();
+				$group->read($id);
+
+				// Ensure we found the group info
+				if (!$group)
+				{
+					continue;
+				}
+
+				// Set the group to be archived
+				$group->set('published', 2);
+				$group->update();
+
+				// log publishing
+				Log::log(array(
+					'gidNumber' => $group->get('gidNumber'),
+					'action'    => 'group_archived',
+					'comments'  => 'archived by administrator'
+				));
+
+				$i++;
+			}
+
+			// Output messsage and redirect
+			if ($i)
+			{
+				Notify::success(Lang::txt('COM_GROUPS_SUCCESS_ARCHIVED', $i));
+			}
+		}
+
+		$this->cancelTask();
 	}
 
 	/**
@@ -1198,6 +1291,14 @@ class Manage extends AdminController
 	 */
 	public function approveTask()
 	{
+		// Check for request forgeries
+		Request::checkToken(['get', 'post']);
+
+		if (!User::authorise('core.edit.state', $this->_option))
+		{
+			App::abort(403, Lang::txt('JERROR_ALERTNOAUTHOR'));
+		}
+
 		// Incoming
 		$ids = Request::getVar('id', array());
 
@@ -1207,6 +1308,8 @@ class Manage extends AdminController
 			$ids = array($ids);
 		}
 
+		$i = 0;
+
 		// Do we have any IDs?
 		if (!empty($ids))
 		{
@@ -1233,15 +1336,18 @@ class Manage extends AdminController
 					'action'    => 'group_approved',
 					'comments'  => 'approved by administrator'
 				));
+
+				$i++;
 			}
 
-			Notify::success(Lang::txt('COM_GROUPS_APPROVED'));
+			if ($i)
+			{
+				Notify::success(Lang::txt('COM_GROUPS_APPROVED'));
+			}
 		}
 
 		// Output messsage and redirect
-		App::redirect(
-			Route::url('index.php?option=' . $this->_option . '&controller=' . $this->_controller, false)
-		);
+		$this->cancelTask();
 	}
 
 	/**
@@ -1251,6 +1357,14 @@ class Manage extends AdminController
 	 */
 	public function unapproveTask()
 	{
+		// Check for request forgeries
+		Request::checkToken(['get', 'post']);
+
+		if (!User::authorise('core.edit.state', $this->_option))
+		{
+			App::abort(403, Lang::txt('JERROR_ALERTNOAUTHOR'));
+		}
+
 		// Incoming
 		$ids = Request::getVar('id', array());
 
@@ -1260,6 +1374,8 @@ class Manage extends AdminController
 			$ids = array($ids);
 		}
 
+		$i = 0;
+
 		// Do we have any IDs?
 		if (!empty($ids))
 		{
@@ -1286,15 +1402,18 @@ class Manage extends AdminController
 					'action'    => 'group_unapproved',
 					'comments'  => 'unapproved by administrator'
 				));
+
+				$i++;
 			}
 
-			Notify::success(Lang::txt('COM_GROUPS_UNAPPROVED'));
+			if ($i)
+			{
+				Notify::success(Lang::txt('COM_GROUPS_UNAPPROVED'));
+			}
 		}
 
 		// Output messsage and redirect
-		App::redirect(
-			Route::url('index.php?option=' . $this->_option . '&controller=' . $this->_controller, false)
-		);
+		$this->cancelTask();
 	}
 
 	/**
