@@ -245,7 +245,7 @@ class Projects extends Base
 		$this->view->filters['search']   = Request::getVar('search', '');
 		$this->view->filters['sortdir']  = strtoupper(Request::getWord('sortdir', 'ASC'));
 		$this->view->filters['reviewer'] = $reviewer;
-		$this->view->filters['filterby'] = 'all';
+		$this->view->filters['filterby'] = Request::getWord('filterby', 'all');
 
 		if (!in_array($this->view->filters['sortby'], array('title', 'id', 'myprojects', 'owner', 'created', 'type', 'role', 'privacy', 'status')))
 		{
@@ -257,10 +257,15 @@ class Projects extends Base
 			$this->view->filters['sortdir'] = 'ASC';
 		}
 
-		if ($reviewer == 'sensitive' || $reviewer == 'sponsored')
+		if (!in_array($this->view->filters['filterby'], array('all', 'public', 'archived', 'pending')))
+		{
+			$this->view->filters['sortdir'] = 'all';
+		}
+
+		/*if ($reviewer == 'sensitive' || $reviewer == 'sponsored')
 		{
 			$this->view->filters['filterby'] = Request::getWord('filterby', 'pending');
-		}
+		}*/
 
 		// Login for private projects
 		if (User::isGuest() && $action == 'login')
@@ -804,7 +809,6 @@ class Projects extends Base
 
 		// Send to continue setup
 		App::redirect(Route::url($this->model->link('setup')));
-		return;
 	}
 
 	/**
@@ -933,7 +937,6 @@ class Projects extends Base
 
 		$this->_task = 'view';
 		$this->viewTask();
-		return;
 	}
 
 	/**
@@ -944,12 +947,12 @@ class Projects extends Base
 	public function authTask()
 	{
 		// Incoming
-		$error  = Request::getVar('error', '', 'get');
-		$code   = Request::getVar('code', '', 'get');
+		$error = Request::getVar('error', '', 'get');
+		$code  = Request::getVar('code', '', 'get');
 
-		$state  = Request::getVar('state', '', 'get');
-		$json	=  base64_decode($state);
-		$json 	=  json_decode($json);
+		$state = Request::getVar('state', '', 'get');
+		$json  = base64_decode($state);
+		$json  = json_decode($json);
 
 		$this->_identifier = $json->alias;
 		$this->model = new Models\Project($this->_identifier);
@@ -983,7 +986,6 @@ class Projects extends Base
 		}
 
 		App::redirect($return);
-		return;
 	}
 
 	/**
@@ -1100,8 +1102,7 @@ class Projects extends Base
 				{
 					if ($approve == 1)
 					{
-						$cbase  .= '<nb:' . $reviewer . '>' . Lang::txt('COM_PROJECTS_PROJECT_APPROVED_SPS') . ' '
-						. ucfirst(Lang::txt('COM_PROJECTS_APPROVAL_CODE')) . ': ' . $grant_approval;
+						$cbase  .= '<nb:' . $reviewer . '>' . Lang::txt('COM_PROJECTS_PROJECT_APPROVED_SPS') . ' ' . ucfirst(Lang::txt('COM_PROJECTS_APPROVAL_CODE')) . ': ' . $grant_approval;
 						$cbase  .= (trim($comment) != '') ? '. ' . $comment : '';
 						$cbase  .= $meta . '</nb:' . $reviewer . '>';
 					}
