@@ -40,30 +40,30 @@ class Project extends \JTable
 	/**
 	 * Constructor
 	 *
-	 * @param      object &$db JDatabase
-	 * @return     void
+	 * @param   object  &$db  Database
+	 * @return  void
 	 */
-	public function __construct( &$db )
+	public function __construct(&$db)
 	{
-		parent::__construct( '#__projects', 'id', $db );
+		parent::__construct('#__projects', 'id', $db);
 	}
 
 	/**
 	 * Validate data
 	 *
-	 * @return     boolean True if data is valid
+	 * @return  boolean  True if data is valid
 	 */
 	public function check()
 	{
-		if (trim( $this->alias ) == '')
+		if (trim($this->alias) == '')
 		{
-			$this->setError( Lang::txt('PROJECT_MUST_HAVE_ALIAS') );
+			$this->setError(Lang::txt('PROJECT_MUST_HAVE_ALIAS'));
 			return false;
 		}
 
-		if (trim( $this->title ) == '')
+		if (trim($this->title) == '')
 		{
-			$this->setError( Lang::txt('PROJECT_MUST_HAVE_TITLE') );
+			$this->setError(Lang::txt('PROJECT_MUST_HAVE_TITLE'));
 			return false;
 		}
 
@@ -73,25 +73,25 @@ class Project extends \JTable
 	/**
 	 * Build query
 	 *
-	 * @param      array $filters
-	 * @param      boolean $admin
-	 * @param      integer $uid
-	 * @param      boolean $showall
-	 * @param      integer $setup_complete
-	 * @return     string
+	 * @param   array    $filters
+	 * @param   boolean  $admin
+	 * @param   integer  $uid
+	 * @param   boolean  $showall
+	 * @param   integer  $setup_complete
+	 * @return  string
 	 */
-	public function buildQuery( $filters=array(), $admin = false, $uid = 0, $showall = 0, $setup_complete = 3 )
+	public function buildQuery($filters=array(), $admin = false, $uid = 0, $showall = 0, $setup_complete = 3)
 	{
 		// Process filters
-		$mine 		= isset($filters['mine']) && $filters['mine'] == 1 ? 1: 0;
-		$sortby 	= isset($filters['sortby']) ? $filters['sortby'] : 'title';
-		$search 	= isset($filters['search']) && $filters['search'] != ''  ? $filters['search'] : '';
-		$filterby 	= isset($filters['filterby']) && $filters['filterby'] != ''  ? $filters['filterby'] : '';
-		$getowner 	= isset($filters['getowner']) && $filters['getowner'] == 1 ? 1: 0;
-		$type 		= isset($filters['type']) ? intval($filters['type']) : NULL;
-		$group 		= isset($filters['group']) && intval($filters['group']) > 0 ? $filters['group'] : '';
-		$reviewer 	= isset($filters['reviewer']) && $filters['reviewer'] != '' ? $filters['reviewer'] : '';
-		$which 		= isset($filters['which'])
+		$mine     = isset($filters['mine']) && $filters['mine'] == 1 ? 1: 0;
+		$sortby   = isset($filters['sortby']) ? $filters['sortby'] : 'title';
+		$search   = isset($filters['search']) && $filters['search'] != ''  ? $filters['search'] : '';
+		$filterby = isset($filters['filterby']) && $filters['filterby'] != ''  ? $filters['filterby'] : '';
+		$getowner = isset($filters['getowner']) && $filters['getowner'] == 1 ? 1: 0;
+		$type     = isset($filters['type']) ? intval($filters['type']) : null;
+		$group    = isset($filters['group']) && intval($filters['group']) > 0 ? $filters['group'] : '';
+		$reviewer = isset($filters['reviewer']) && $filters['reviewer'] != '' ? $filters['reviewer'] : '';
+		$which    = isset($filters['which'])
 					&& $filters['which'] != ''
 					&& $filters['which'] != 'all'
 					? $filters['which'] : '';
@@ -121,14 +121,14 @@ class Project extends \JTable
 			$query .= " OR p.params LIKE '%export_data=yes%' ";
 			$query .= " OR p.params LIKE 'restricted_data=maybe%' ";
 			$query .= " OR p.params LIKE '%followup=yes%') ";
-			$query .= " AND p.state != 2 AND p.setup_stage >= " . $this->_db->quote($setup_complete) . " ) ";
+			$query .= " AND p.state != 2 AND p.setup_stage >= " . $this->_db->quote($setup_complete) . ") ";
 		}
 		elseif ($reviewer == 'sponsored')
 		{
-			$query .= " WHERE ((( p.params LIKE '%grant_title=%' AND p.params NOT LIKE '%grant_title=\\n%') ";
-			$query .= " OR ( p.params LIKE '%grant_agency=%' AND p.params NOT LIKE '%grant_agency=\\n%') ";
-			$query .= " OR ( p.params LIKE '%grant_budget=%' AND p.params NOT LIKE '%grant_budget=\\n%') ";
-			$query .= " ) AND p.state=1 AND p.setup_stage >= " . $this->_db->quote($setup_complete) . " ) ";
+			$query .= " WHERE (((p.params LIKE '%grant_title=%' AND p.params NOT LIKE '%grant_title=\\n%') ";
+			$query .= " OR (p.params LIKE '%grant_agency=%' AND p.params NOT LIKE '%grant_agency=\\n%') ";
+			$query .= " OR (p.params LIKE '%grant_budget=%' AND p.params NOT LIKE '%grant_budget=\\n%') ";
+			$query .= ") AND p.state=1 AND p.setup_stage >= " . $this->_db->quote($setup_complete) . ") ";
 		}
 		elseif ($admin)
 		{
@@ -142,7 +142,7 @@ class Project extends \JTable
 				$query .= $uid
 						? " WHERE (o.userid=" . $this->_db->quote($uid) . " AND o.status!=2
 							AND ((p.state != 2 AND p.setup_stage >= " . $this->_db->quote($setup_complete) . ")
-							OR (o.role = 1 AND p.owned_by_user=" . $this->_db->quote($uid) . " ))) "
+							OR (o.role = 1 AND p.owned_by_user=" . $this->_db->quote($uid) . "))) "
 						: " WHERE 1=2";
 				if (!empty($filters['editor']))
 				{
@@ -159,12 +159,19 @@ class Project extends \JTable
 			}
 			else
 			{
-				$query .= $uid
-						? " WHERE ((p.state = 1 AND p.private = 0)
-							OR (o.userid=" . $this->_db->quote($uid) . " AND o.status!=2 AND ((p.state = 1
-							AND p.setup_stage >= " . $this->_db->quote($setup_complete) . ")
-							OR (o.role = 1 AND p.owned_by_user=" . $this->_db->quote($uid) . ")))) "
-						: " WHERE p.state = 1 AND p.private = 0 ";
+				if ($filterby == 'archived')
+				{
+					$query .= " WHERE p.state = 3 AND p.private = 0 ";
+				}
+				else
+				{
+					$query .= $uid
+							? " WHERE ((p.state = 1 AND p.private = 0)
+								OR (o.userid=" . $this->_db->quote($uid) . " AND o.status!=2 AND ((p.state = 1
+								AND p.setup_stage >= " . $this->_db->quote($setup_complete) . ")
+								OR (o.role = 1 AND p.owned_by_user=" . $this->_db->quote($uid) . " AND p.state != 3)))) "
+							: " WHERE p.state = 1 AND p.private = 0 ";
+				}
 			}
 		}
 		if ($type)
@@ -192,7 +199,7 @@ class Project extends \JTable
 		}
 		if ($search)
 		{
-			$query .= " AND (p.title LIKE '%" . $search . "%' OR p.alias LIKE '%" . $search . "%') ";
+			$query .= " AND (p.title LIKE " . $this->_db->quote('%' . $search . '%') . " OR p.alias LIKE " . $this->_db->quote('%' . $search . '%') . ") ";
 		}
 
 		if (isset($filters['private']))
@@ -203,7 +210,7 @@ class Project extends \JTable
 		// Exclude
 		if (!empty($filters['exclude']))
 		{
-			$query .= " AND p.id NOT IN ( ";
+			$query .= " AND p.id NOT IN (";
 
 			$tquery = '';
 			foreach ($filters['exclude'] as $ex)
@@ -217,15 +224,12 @@ class Project extends \JTable
 		// Include
 		if (!empty($filters['include']))
 		{
-			$query .= " AND p.id IN ( ";
-
-			$tquery = '';
+			$tquery = array();
 			foreach ($filters['include'] as $ex)
 			{
-				$tquery .= "'" . $ex . "',";
+				$tquery[] = $this->_db->quote($ex);
 			}
-			$tquery = substr($tquery, 0, strlen($tquery) - 1);
-			$query .= $tquery . ") ";
+			$query .= " AND p.id IN (" . implode(',', $tquery) . ") ";
 		}
 
 		if (isset($filters['created']))
@@ -274,8 +278,7 @@ class Project extends \JTable
 					}
 					else
 					{
-						$sort .= 'p.owned_by_group ' . $sortdir
-							  . ', p.owned_by_user ' . $sortdir . ' ';
+						$sort .= 'p.owned_by_group ' . $sortdir . ', p.owned_by_user ' . $sortdir . ' ';
 					}
 					break;
 
@@ -297,7 +300,7 @@ class Project extends \JTable
 
 				case 'status':
 					$sort .= 'p.setup_stage ' . $sortdir . ', p.state '
-						  . $sortdir . ', p.created ' . $sortdir;
+						. $sortdir . ', p.created ' . $sortdir;
 					break;
 
 				default:
@@ -314,42 +317,42 @@ class Project extends \JTable
 	/**
 	 * Get item count
 	 *
-	 * @param      array $filters
-	 * @param      boolean $admin
-	 * @param      integer $uid
-	 * @param      boolean $showall
-	 * @param      integer $setup_complete
-	 * @return     integer
+	 * @param   array    $filters
+	 * @param   boolean  $admin
+	 * @param   integer  $uid
+	 * @param   boolean  $showall
+	 * @param   integer  $setup_complete
+	 * @return  integer
 	 */
-	public function getCount( $filters = array(), $admin = false, $uid = 0 , $showall = 0, $setup_complete = 3 )
+	public function getCount($filters = array(), $admin = false, $uid = 0 , $showall = 0, $setup_complete = 3)
 	{
 		$filters['count'] = true;
 		$admin = $admin == 'admin' ? true : false;
 
 		$query  = "SELECT count(DISTINCT p.id) ";
-		$query .= $this->buildQuery( $filters, $admin, $uid, $showall, $setup_complete );
+		$query .= $this->buildQuery($filters, $admin, $uid, $showall, $setup_complete);
 
-		$this->_db->setQuery( $query );
+		$this->_db->setQuery($query);
 		return $this->_db->loadResult();
 	}
 
 	/**
 	 * Get records
 	 *
-	 * @param      array $filters
-	 * @param      boolean $admin
-	 * @param      integer $uid
-	 * @param      boolean $showall
-	 * @param      integer $setup_complete
-	 * @return     object
+	 * @param   array    $filters
+	 * @param   boolean  $admin
+	 * @param   integer  $uid
+	 * @param   boolean  $showall
+	 * @param   integer  $setup_complete
+	 * @return  object
 	 */
-	public function getRecords( $filters = array(), $admin = false, $uid = 0, $showall = 0, $setup_complete = 3 )
+	public function getRecords($filters = array(), $admin = false, $uid = 0, $showall = 0, $setup_complete = 3)
 	{
-		$filters['count'] 	= false;
-		$admin 				= $admin == 'admin' ? true : false;
-		$updates 			= isset($filters['updates']) && $filters['updates'] == 1 ? 1: 0;
-		$getowner 			= isset($filters['getowner']) && $filters['getowner'] == 1 ? 1: 0;
-		$activity 			= isset($filters['activity']) && $filters['activity'] == 1 ? 1: 0;
+		$filters['count'] = false;
+		$admin    = $admin == 'admin' ? true : false;
+		$updates  = isset($filters['updates']) && $filters['updates'] == 1 ? 1: 0;
+		$getowner = isset($filters['getowner']) && $filters['getowner'] == 1 ? 1: 0;
+		$activity = isset($filters['activity']) && $filters['activity'] == 1 ? 1: 0;
 
 		$query  = "SELECT p.*, IFNULL(o.role, 0) as role, o.id as owner, o.added as since, o.status as confirmed ";
 
@@ -365,14 +368,14 @@ class Project extends \JTable
 						WHERE pa.projectid=p.id AND pa.recorded >= o.lastvisit
 						AND o.lastvisit IS NOT NULL AND o.id IS NOT NULL
 						AND pa.state != 2 AND (pa.managers_only = 0
-						OR (pa.managers_only=1 AND o.role=1)) ) as newactivity ";
+						OR (pa.managers_only=1 AND o.role=1))) as newactivity ";
 		}
 		if ($activity)
 		{
 			$query .= ", (SELECT COUNT(*) FROM #__project_activity AS pa
-						WHERE pa.projectid=p.id AND pa.state != 2 ) as activity ";
+						WHERE pa.projectid=p.id AND pa.state != 2) as activity ";
 		}
-		$query .= $this->buildQuery( $filters, $admin, $uid, $showall, $setup_complete );
+		$query .= $this->buildQuery($filters, $admin, $uid, $showall, $setup_complete);
 
 		if (isset($filters['limit']) && $filters['limit'] != 'all' && $filters['limit'] != 0)
 		{
@@ -380,16 +383,19 @@ class Project extends \JTable
 			$query .= " LIMIT " . $filters['start'] . "," . $filters['limit'];
 		}
 
-		$this->_db->setQuery( $query );
+		$this->_db->setQuery($query);
 		return $this->_db->loadObjectList();
 	}
 
 	/**
 	 * Get project ids/aliased by tag
 	 *
-	 * @return     array
+	 * @param   string  $tag
+	 * @param   bool    $include
+	 * @param   string  $get
+	 * @return  array
 	 */
-	public function getProjectsByTag( $tag = 'test', $include = true, $get = 'id')
+	public function getProjectsByTag($tag = 'test', $include = true, $get = 'id')
 	{
 		$ids = array();
 
@@ -397,11 +403,11 @@ class Project extends \JTable
 		$query  = "SELECT DISTINCT p.$get, ";
 		$query .= "(SELECT COUNT(*) FROM #__tags_object AS RTA
 					JOIN #__tags AS TA ON RTA.tagid = TA.id
-		  			AND RTA.tbl='projects'
-		  			WHERE TA.tag=" . $this->_db->quote($tag) . " AND RTA.objectid=p.id) as count";
+					AND RTA.tbl='projects'
+					WHERE TA.tag=" . $this->_db->quote($tag) . " AND RTA.objectid=p.id) as count";
 		$query .= " FROM $this->_tbl AS p ";
 
-		$this->_db->setQuery( $query );
+		$this->_db->setQuery($query);
 		$result = $this->_db->loadObjectList();
 		if ($result)
 		{
@@ -420,22 +426,21 @@ class Project extends \JTable
 	/**
 	 * Get group projects
 	 *
-	 * @param      integer $groupid
-	 * @param      integer $uid
-	 * @param      array $filters
-	 * @param      integer $setup_complete
-	 * @return     object
+	 * @param   integer  $groupid
+	 * @param   integer  $uid
+	 * @param   array    $filters
+	 * @param   integer  $setup_complete
+	 * @return  object
 	 */
-	public function getGroupProjects ( $groupid = 0, $uid = 0, $filters = array(), $setup_complete = 3 )
+	public function getGroupProjects($groupid = 0, $uid = 0, $filters = array(), $setup_complete = 3)
 	{
 		$query  = "SELECT DISTINCT p.*, IFNULL(o.role, 0) as role, o.id as owner, o.added as since, o.status as confirmed ";
 		$query .= ", x.name as authorname, g.cn as groupcn, g.description as groupname ";
 		$query .= ", (SELECT COUNT(*) FROM #__project_activity AS pa WHERE pa.projectid=p.id
 					AND pa.recorded >= o.lastvisit AND o.lastvisit IS NOT NULL
-					AND o.id IS NOT NULL AND pa.state != 2 ) as newactivity ";
+					AND o.id IS NOT NULL AND pa.state != 2) as newactivity ";
 		$query .= " FROM #__project_owners as po, $this->_tbl AS p";
-		$query .= " LEFT JOIN #__project_owners AS o ON o.projectid=p.id AND o.userid="
-					. $this->_db->quote($uid) . " AND o.userid != 0 AND p.state!= 2 ";
+		$query .= " LEFT JOIN #__project_owners AS o ON o.projectid=p.id AND o.userid=" . $this->_db->quote($uid) . " AND o.userid != 0 AND p.state!= 2 ";
 		$query .=  " JOIN #__xprofiles as x ON x.uidNumber=p.created_by_user ";
 		$query .=  " LEFT JOIN #__xgroups as g ON g.gidNumber=p.owned_by_group ";
 		$query .=  " WHERE p.id=po.projectid AND p.state !=2 AND po.status=1 AND po.groupid=" . $groupid;
@@ -457,7 +462,7 @@ class Project extends \JTable
 				: " AND p.state = 1 ";
 
 		// Sorting
-		if (!isset($filters['count']) OR $filters['count'] == 0)
+		if (!isset($filters['count']) or $filters['count'] == 0)
 		{
 			$sort = '';
 			$sortby  = isset($filters['sortby']) ? $filters['sortby'] : 'title';
@@ -470,7 +475,7 @@ class Project extends \JTable
 					break;
 
 				case 'status':
-					$sort .= 'p.setup_stage ' . $sortdir . ', p.state ' . $sortdir . ', p.title ASC' ;
+					$sort .= 'p.setup_stage ' . $sortdir . ', p.state ' . $sortdir . ', p.title ASC';
 					break;
 
 				case 'title':
@@ -484,7 +489,7 @@ class Project extends \JTable
 
 		if (isset($filters['count']) && $filters['count'] == 1)
 		{
-			$this->_db->setQuery( $query );
+			$this->_db->setQuery($query);
 			return $this->_db->loadResult();
 		}
 		else if (isset($filters['limit']) && $filters['limit'] != 'all' && $filters['limit'] != 0)
@@ -493,19 +498,19 @@ class Project extends \JTable
 			$query .= " LIMIT " . $filters['start'] . "," . $filters['limit'];
 		}
 
-		$this->_db->setQuery( $query );
+		$this->_db->setQuery($query);
 		return $this->_db->loadObjectList();
 	}
 
 	/**
 	 * Get user project ids
 	 *
-	 * @param      integer $uid
-	 * @param      integer $active
-	 * @param      integer $include_provisioned
-	 * @return     array
+	 * @param   integer  $uid
+	 * @param   integer  $active
+	 * @param   integer  $include_provisioned
+	 * @return  array
 	 */
-	public function getUserProjectIds ( $uid = 0, $active = 1, $include_provisioned = 0 )
+	public function getUserProjectIds($uid = 0, $active = 1, $include_provisioned = 0)
 	{
 		$ids = array();
 
@@ -519,7 +524,7 @@ class Project extends \JTable
 					: "AND p.state !=2 ";
 			$query .= $include_provisioned ? "" : " AND p.provisioned=0";
 			$query .= " AND o.userid=" . $uid;
-			$this->_db->setQuery( $query );
+			$this->_db->setQuery($query);
 			$result = $this->_db->loadObjectList();
 			if ($result)
 			{
@@ -528,20 +533,20 @@ class Project extends \JTable
 					$ids[] = $r->id;
 				}
 			}
-
 		}
+
 		return $ids;
 	}
 
 	/**
 	 * Get project ids for a group
 	 *
-	 * @param      integer $groupid
-	 * @param      integer $uid
-	 * @param      integer $active
-	 * @return     array
+	 * @param   integer  $groupid
+	 * @param   integer  $uid
+	 * @param   integer  $active
+	 * @return  array
 	 */
-	public function getGroupProjectIds ( $groupid = 0, $uid = 0, $active = 1 )
+	public function getGroupProjectIds($groupid = 0, $uid = 0, $active = 1)
 	{
 		$ids = array();
 
@@ -556,7 +561,7 @@ class Project extends \JTable
 					? " AND (p.state=1 OR (o.role = 1 AND p.owned_by_user=" . $this->_db->quote($uid) . " AND p.state !=2))  "
 					: " AND p.state !=2 ";
 			$query .= " AND p.provisioned=0";
-			$this->_db->setQuery( $query );
+			$this->_db->setQuery($query);
 			$result = $this->_db->loadObjectList();
 			if ($result)
 			{
@@ -565,55 +570,54 @@ class Project extends \JTable
 					$ids[] = $r->id;
 				}
 			}
-
 		}
+
 		return $ids;
 	}
 
 	/**
 	 * Get count of new activity since user last visit (multiple projects)
 	 *
-	 * @param      array $projects
-	 * @param      integer $uid
-	 * @return     integer
+	 * @param   array    $projects
+	 * @param   integer  $uid
+	 * @return  integer
 	 */
-	public function getUpdateCount ($projects = array(), $uid = 0)
+	public function getUpdateCount($projects = array(), $uid = 0)
 	{
 		if (!empty($projects) && $uid != 0)
 		{
-			$query  = "SELECT COUNT(*) FROM #__project_activity AS pa ";
-			$query .= " JOIN #__project_owners as o ON o.projectid=pa.projectid AND o.userid=" . $this->_db->quote($uid);
+			$query  = "SELECT COUNT(*) FROM `#__project_activity` AS pa ";
+			$query .= " JOIN `#__project_owners` as o ON o.projectid=pa.projectid AND o.userid=" . $this->_db->quote($uid);
 			$query .= " WHERE pa.recorded >= o.lastvisit AND o.lastvisit IS NOT NULL
 						AND pa.state !=2 AND pa.recorded >= o.added";
-			$query .= " AND pa.projectid IN ( ";
+			$query .= " AND pa.projectid IN (";
 
-			$tquery = '';
+			$tquery = array();
 			foreach ($projects as $project)
 			{
-				$tquery .= "'".$project."',";
+				$tquery[] = $this->_db->quote($project);
 			}
-			$tquery = substr($tquery,0,strlen($tquery) - 1);
-			$query .= $tquery.") ";
-			$this->_db->setQuery( $query );
+
+			$query .= implode(',', $tquery) . ") ";
+			$this->_db->setQuery($query);
+
 			return $this->_db->loadResult();
 		}
-		else
-		{
-			return 0;
-		}
+
+		return 0;
 	}
 
 	/**
 	 * Get project
 	 *
-	 * @param      string $identifier
-	 * @param      integer $uid
-	 * @param      integer $pubid
-	 * @return     mixed (array or false)
+	 * @param   string   $identifier
+	 * @param   integer  $uid
+	 * @param   integer  $pubid
+	 * @return  mixed    (array or false)
 	 */
-	public function getProject( $identifier = NULL, $uid = 0, $pubid = 0 )
+	public function getProject($identifier = null, $uid = 0, $pubid = 0)
 	{
-		if ($identifier === NULL && !$pubid)
+		if ($identifier === null && !$pubid)
 		{
 			return false;
 		}
@@ -621,7 +625,7 @@ class Project extends \JTable
 		$query  = "SELECT p.*, IFNULL(o.role, 0) as role, o.groupid as owner_group,
 				   o.id as owner, o.added as since, o.lastvisit, o.num_visits,
 				   o.params as owner_params, o.status as confirmed, ";
-		$query .= " x.name, x.username, x.name as fullname ";
+		$query .= " u.name, u.username, u.name as fullname ";
 		$query .= " ,(SELECT t.type FROM #__project_types as t WHERE t.id=p.type) as projecttype ";
 
 		if (intval($pubid) > 0)
@@ -634,12 +638,12 @@ class Project extends \JTable
 		}
 		$query .= " LEFT JOIN #__project_owners AS o ON o.projectid=p.id ";
 		$query .= " AND o.userid=" . $this->_db->quote($uid) . " AND p.state!= 2 AND o.userid != 0 AND o.status !=2";
-		$query .=  " JOIN #__xprofiles as x ON x.uidNumber=p.owned_by_user ";
+		$query .=  " JOIN #__users as u ON u.id=p.owned_by_user ";
 		$query .= " WHERE ";
 
 		if (intval($pubid) > 0)
 		{
-			$query .= " pu.id=".$pubid;
+			$query .= " pu.id=" . $pubid;
 		}
 		else
 		{
@@ -649,56 +653,56 @@ class Project extends \JTable
 		}
 		$query .= " LIMIT 1";
 
-		$this->_db->setQuery( $query );
+		$this->_db->setQuery($query);
 		$result = $this->_db->loadObjectList();
-		return $result ? $result[0] : NULL;
+		return $result ? $result[0] : null;
 	}
 
 	/**
 	 * Select item
 	 *
-	 * @param      string $select
-	 * @param      string $where
-	 * @param      integer $limit
-	 * @return     mixed (string or object)
+	 * @param   string   $select
+	 * @param   string   $where
+	 * @param   integer  $limit
+	 * @return  mixed    (string or object)
 	 */
-	public function selectWhere( $select, $where, $limit = 0 )
+	public function selectWhere($select, $where, $limit = 0)
 	{
 		$query  = "SELECT $select FROM $this->_tbl WHERE $where";
 		$query .= $limit ? " LIMIT 1 " : "";
 
-		$this->_db->setQuery( $query );
+		$this->_db->setQuery($query);
 		return $limit ? $this->_db->loadResult() : $this->_db->loadObjectList();
 	}
 
 	/**
 	 * Get project alias from ID
 	 *
-	 * @param      integer $id
-	 * @return     string
+	 * @param   integer  $id
+	 * @return  string
 	 */
-	public function getAlias( $id = 0 )
+	public function getAlias($id = 0)
 	{
 		if (!$id)
 		{
 			return false;
 		}
 		$query = "SELECT alias FROM $this->_tbl WHERE id=" . $this->_db->quote($id);
-		$this->_db->setQuery( $query );
+		$this->_db->setQuery($query);
 		return $this->_db->loadResult();
 	}
 
 	/**
 	 * Save project parameter
 	 *
-	 * @param      integer $projectid
-	 * @param      string $param
-	 * @param      string $value
-	 * @return     void
+	 * @param   integer  $projectid
+	 * @param   string   $param
+	 * @param   string   $value
+	 * @return  void
 	 */
-	public function saveParam ( $projectid = NULL, $param = '', $value = 0 )
+	public function saveParam($projectid = null, $param = '', $value = 0)
 	{
-		if ($projectid === NULL)
+		if ($projectid === null)
 		{
 			return false;
 		}
@@ -728,7 +732,8 @@ class Project extends \JTable
 								$default = isset($extracted[1]) ? $extracted[1] : 0;
 								$in .= $extracted[0] == $param ? $value : $default;
 								$in	.= "\n";
-								if ($extracted[0] == $param) {
+								if ($extracted[0] == $param)
+								{
 									$found = 1;
 								}
 							}
@@ -752,68 +757,65 @@ class Project extends \JTable
 	/**
 	 * Load a record and bind to $this
 	 *
-	 * @param      string $identifier project id or alias name
-	 * @return     object or false
+	 * @param   string  $identifier   project id or alias name
+	 * @return  mixed   object or false
 	 */
-	public function loadProject ( $identifier = NULL )
+	public function loadProject($identifier = null)
 	{
-		if ($identifier === NULL)
+		if ($identifier === null)
 		{
 			return false;
 		}
 		$name = is_numeric($identifier) ? 'id' : 'alias';
 
-		$this->_db->setQuery( "SELECT * FROM $this->_tbl WHERE $name=" . $this->_db->quote($identifier) . " LIMIT 1" );
+		$this->_db->setQuery("SELECT * FROM $this->_tbl WHERE $name=" . $this->_db->quote($identifier) . " LIMIT 1");
 		if ($result = $this->_db->loadAssoc())
 		{
-			return $this->bind( $result );
-		}
-		else
-		{
-			return false;
+			return $this->bind($result);
 		}
+
+		return false;
 	}
 
 	/**
 	 * Load a record and bind to $this
 	 *
-	 * @param      string $identifier project id or alias name
-	 * @return     object or false
+	 * @param   string  $identifier   project id or alias name
+	 * @return  mixed   object or false
 	 */
-	public function loadProvisionedProject ( $pid = NULL )
+	public function loadProvisionedProject($pid = null)
 	{
 		if (!intval($pid))
 		{
 			return false;
 		}
 
-		$this->_db->setQuery( "SELECT p.* FROM #__publications AS pu JOIN $this->_tbl AS p ON pu.project_id=p.id WHERE pu.id=" . $this->_db->quote($pid) . " LIMIT 1" );
+		$this->_db->setQuery("SELECT p.* FROM `#__publications` AS pu JOIN $this->_tbl AS p ON pu.project_id=p.id WHERE pu.id=" . $this->_db->quote($pid) . " LIMIT 1");
 		if ($result = $this->_db->loadAssoc())
 		{
-			return $this->bind( $result );
-		}
-		else
-		{
-			return false;
+			return $this->bind($result);
 		}
+
+		return false;
 	}
 
 	/**
 	 * Check if name is unique
 	 *
-	 * @param      string $name
-	 * @param      integer $pid
-	 * @return     boolean
+	 * @param   string   $name
+	 * @param   integer  $pid
+	 * @return  boolean
 	 */
-	public function checkUniqueName ( $name, $pid = 0 )
+	public function checkUniqueName($name, $pid = 0)
 	{
-		if ($name === NULL) {
+		if ($name === null)
+		{
 			return false;
 		}
 		$query  =  "SELECT id FROM $this->_tbl WHERE alias=" . $this->_db->quote($name);
 		$query .= $pid ? " AND id!=" . $this->_db->quote($pid) : "";
 		$query .= " LIMIT 1 ";
-		$this->_db->setQuery( $query );
+		$this->_db->setQuery($query);
 		if ($this->_db->loadResult())
 		{
 			return false;
@@ -824,29 +826,31 @@ class Project extends \JTable
 	/**
 	 * Save setup stage
 	 *
-	 * @param      integer $projectid
-	 * @param      integer $stage
-	 * @return     boolean
+	 * @param   integer  $projectid
+	 * @param   integer  $stage
+	 * @return  boolean
 	 */
-	public function saveStage ( $projectid = NULL, $stage = 0 )
+	public function saveStage($projectid = null, $stage = 0)
 	{
-		if ($projectid === NULL)
+		if ($projectid === null)
 		{
 			return false;
 		}
 		$query  = "SELECT * FROM $this->_tbl WHERE id=" . $this->_db->quote($projectid) . " LIMIT 1";
-		$this->_db->setQuery( $query );
+		$this->_db->setQuery($query);
 
 		if ($result = $this->_db->loadAssoc())
 		{
-			$this->bind( $result );
+			$this->bind($result);
 			$this->setup_stage = $stage;
 			if (!$this->store())
 			{
-				$this->setError( Lang::txt('Failed to update setup stage.') );
+				$this->setError(Lang::txt('Failed to update setup stage.'));
 				return false;
 			}
 			return true;
 		}
+
+		return false;
 	}
 }
