@@ -294,6 +294,17 @@ class Curation extends Object
 		return $blockId;
 	}
 
+	/**
+	 * getBlockSchema - returns the Blocks of this curation flow 
+	 * 
+	 * @access public
+	 * @return void
+	 */
+	public function getBlockSchema()
+	{
+		return $this->_blocks;
+	}
+
 	/**
 	 * Get schema for metadata elements
 	 *
