@@ -33,7 +33,7 @@ namespace Components\Wiki\Models\Adapters;
 
 use User;
 
-require_once(__DIR__ . DS . 'base.php');
+require_once __DIR__ . DS . 'base.php';
 
 /**
  * Adapter class for a group wiki
@@ -181,7 +181,7 @@ class Group extends Base
 		}
 
 		// Is this a group manager?
-		if ($group)
+		if ($group && $group->published == 1)
 		{
 			// Is this a group manager?
 			if ($group->is_member_of('managers', User::get('id')))
@@ -247,6 +247,8 @@ class Group extends Base
 			}
 		}
 
+		$page->config()->set('access-check-done', true);
+
 		return true;
 	}
 }
