@@ -38,11 +38,11 @@ $this->css();
 <h3 class="section-header">
 	<?php echo Lang::txt('PLG_GROUPS_RESOURCES'); ?>
 </h3>
-
-<ul id="page_options">
-	<li>
-		<a class="icon-add add btn" href="<?php echo Route::url('index.php?option=com_resources&task=draft&group=' . $this->group->get('cn')); ?>"><?php echo Lang::txt('PLG_GROUPS_RESOURCES_START_A_CONTRIBUTION'); ?></a>
-	</li>
-</ul>
-
+<?php if ($this->group->published == 1) { ?>
+	<ul id="page_options">
+		<li>
+			<a class="icon-add add btn" href="<?php echo Route::url('index.php?option=com_resources&task=draft&group=' . $this->group->get('cn')); ?>"><?php echo Lang::txt('PLG_GROUPS_RESOURCES_START_A_CONTRIBUTION'); ?></a>
+		</li>
+	</ul>
+<?php } ?>
 <?php echo $this->hubgraphResponse;
