@@ -48,14 +48,15 @@ class plgProjectsWatch extends \Hubzero\Plugin\Plugin
 	/**
 	 * Event call to determine if this plugin should return data
 	 *
-	 * @return  array  Plugin name and title
+	 * @param   string  $alias
+	 * @return  array   Plugin name and title
 	 */
-	public function &onProjectAreas($alias = NULL)
+	public function &onProjectAreas($alias = null)
 	{
 		$area = array(
 			'name'    => 'watch',
 			'title'   => 'Watch',
-			'submenu' => NULL,
+			'submenu' => null,
 			'show'    => false
 		);
 
@@ -70,7 +71,7 @@ class plgProjectsWatch extends \Hubzero\Plugin\Plugin
 	 * @param   string  $areas   Plugins to return data
 	 * @return  array   Return array of html
 	 */
-	public function onProject($model, $action = '', $areas = NULL)
+	public function onProject($model, $action = '', $areas = null)
 	{
 		// Get this area details
 		$this->_area = $this->onProjectAreas();
@@ -91,7 +92,7 @@ class plgProjectsWatch extends \Hubzero\Plugin\Plugin
 	 * Return data on a project team member
 	 *
 	 * @param   object  $project  Current publication
-	 * @return  array
+	 * @return  mixed
 	 */
 	public function onProjectMember($project)
 	{
@@ -111,8 +112,8 @@ class plgProjectsWatch extends \Hubzero\Plugin\Plugin
 		$this->project  = $project;
 
 		// Item watch class
-		$this->watch   = new \Hubzero\Item\Watch($this->database);
-		$this->action  = strtolower(Request::getWord('action', ''));
+		$this->watch    = new Hubzero\Item\Watch($this->database);
+		$this->action   = strtolower(Request::getWord('action', ''));
 
 		switch ($this->action)
 		{
@@ -140,7 +141,7 @@ class plgProjectsWatch extends \Hubzero\Plugin\Plugin
 		// Instantiate a view
 		$view = $this->view('default', 'index')
 			->set('project', $this->project)
-			->set('watched', \Hubzero\Item\Watch::isWatching(
+			->set('watched', Hubzero\Item\Watch::isWatching(
 				$this->project->get('id'),
 				'project',
 				User::get('id')
@@ -158,13 +159,13 @@ class plgProjectsWatch extends \Hubzero\Plugin\Plugin
 	private function _manage()
 	{
 		// Is user watching item?
-		$watch = \Hubzero\Item\Watch::oneByScope(
+		$watch = Hubzero\Item\Watch::oneByScope(
 			$this->project->get('id'),
 			'project',
 			User::get('id')
 		);
 
-		$params = new \Hubzero\Config\Registry($watch->get('params', ''));
+		$params = new Hubzero\Config\Registry($watch->get('params', ''));
 
 		$cats = array(
 			'blog'         => $params->get('blog', 0),
@@ -209,7 +210,7 @@ class plgProjectsWatch extends \Hubzero\Plugin\Plugin
 		$frequency  = Request::getWord('frequency', 'immediate');
 
 		// Save subscription
-		$watch = \Hubzero\Item\Watch::oneByScope(
+		$watch = Hubzero\Item\Watch::oneByScope(
 			$this->project->get('id'),
 			'project',
 			User::get('id'),
@@ -231,7 +232,7 @@ class plgProjectsWatch extends \Hubzero\Plugin\Plugin
 			'notes'        => 0
 		);
 
-		$params = new \Hubzero\Config\Registry($watch->get('params', ''));
+		$params = new Hubzero\Config\Registry($watch->get('params', ''));
 
 		$params->set('frequency', $frequency);
 
@@ -279,15 +280,6 @@ class plgProjectsWatch extends \Hubzero\Plugin\Plugin
 	{
 		$this->project = $project;
 
-		// Get subscribers
-		$subscribers = \Hubzero\Item\Watch::all()
-			->whereEquals('item_type', 'project')
-			->whereEquals('item_id', $project->get('id'))
-			->whereEquals('state', 1)
-			->whereLike('params', '"' . $area . '":1')
-			->whereLike('params', '"frequency":"immediate"')
-			->rows();
-
 		// Get full activity info from IDs
 		if ($activities)
 		{
@@ -303,6 +295,55 @@ class plgProjectsWatch extends \Hubzero\Plugin\Plugin
 			return false;
 		}
 
+		// Get subscribers
+		$watchers = Hubzero\Item\Watch::all()
+			->whereEquals('item_type', 'project')
+			->whereEquals('item_id', $project->get('id'))
+			->whereEquals('state', 1);
+
+		if (!$this->params->get('autosubscribe'))
+		{
+			$watchers
+				->whereLike('params', '"' . $area . '":1')
+				->whereLike('params', '"frequency":"immediate"');
+		}
+
+		$subscribers = $watchers->rows();
+
+		// Is auto-subscribed turned on?
+		if ($this->params->get('autosubscribe'))
+		{
+			// Get the entire team
+			$team = $project->table('Owner')->getIds($project->get('id'), 'all', 1);
+
+			// Filter out people who have opted-out
+			foreach ($subscribers as $subscriber)
+			{
+				if (in_array($subscriber->get('created_by'), $team))
+				{
+					$params = new Hubzero\Config\Registry($subscriber->get('params'));
+
+					// Do they meet the requirements for being messaged?
+					if ($params->get('frequency') != 'immediate' || !$params->get($area))
+					{
+						// Unset the user from the team list
+						$key = array_search($subscriber->get('created_by'), $team);
+						unset($team[$key]);
+					}
+				}
+			}
+
+			// Rebuild the subscriber list from the team
+			$subscribers = new Hubzero\Database\Rows();
+			foreach ($team as $t)
+			{
+				$subscriber = new Hubzero\Item\Watch();
+				$subscriber->set('created_by', $t);
+
+				$subscribers->push($subscriber);
+			}
+		}
+
 		$subject = Lang::txt('PLG_PROJECTS_WATCH_EMAIL_SUBJECT');
 
 		// Do we have subscribers?
@@ -315,11 +356,9 @@ class plgProjectsWatch extends \Hubzero\Plugin\Plugin
 					// Skip
 					continue;
 				}
+
 				// Send message
-				if ($subscriber->email)
-				{
-					$this->_sendEmail($project, $subscriber, $activities, $subject);
-				}
+				$this->_sendEmail($project, $subscriber, $activities, $subject);
 			}
 		}
 
@@ -337,26 +376,34 @@ class plgProjectsWatch extends \Hubzero\Plugin\Plugin
 	 */
 	private function _sendEmail($project, $subscriber, $activities = array(), $subject)
 	{
-		$eview = new \Hubzero\Mail\View(array(
+		$name  = Config::get('sitename') . ' ' . Lang::txt('PLG_PROJECTS_WATCH_SUBSCRIBER');
+		$email = $subscriber->get('email');
+
+		// Get profile information
+		if ($subscriber->get('created_by'))
+		{
+			$user = User::getInstance($subscriber->get('created_by'));
+			if ($user->get('id'))
+			{
+				$name  = $user->get('name');
+				$email = $user->get('email');
+			}
+		}
+
+		if (empty($email))
+		{
+			return false;
+		}
+
+		$eview = new Hubzero\Mail\View(array(
 			'base_path' => PATH_CORE . DS . 'components' . DS . 'com_projects' . DS . 'site',
-			'name'   => 'emails',
-			'layout' => 'watch_plain'
+			'name'      => 'emails',
+			'layout'    => 'watch_plain'
 		));
 		$eview->activities = $activities;
 		$eview->subject    = $subject;
 		$eview->project    = $project;
 
-		$name = Config::get('sitename') . ' ' . Lang::txt('PLG_PROJECTS_WATCH_SUBSCRIBER');
-		$email = $subscriber->email;
-
-		// Get profile information
-		if ($subscriber->created_by)
-		{
-			$user  = User::getInstance($subscriber->created_by);
-			$name  = $user ? $user->get('name')  : $name;
-			$email = $user ? $user->get('email') : $email;
-		}
-
 		$plain = $eview->loadTemplate(false);
 		$plain = str_replace("\n", "\r\n", $plain);
 
@@ -366,30 +413,23 @@ class plgProjectsWatch extends \Hubzero\Plugin\Plugin
 		$html = $eview->loadTemplate();
 		$html = str_replace("\n", "\r\n", $html);
 
-		if (empty($email))
-		{
-			return false;
-		}
-
 		// Build message
-		$message = new \Hubzero\Mail\Message();
+		$message = new Hubzero\Mail\Message();
 		$message->setSubject($subject)
 				->addFrom(Config::get('mailfrom'), Config::get('sitename'))
 				->addTo($email, $name)
 				->addHeader('X-Component', 'com_projects')
-				->addHeader('X-Component-Object', 'projects_watch_email');
-
-		$message->addPart($plain, 'text/plain');
-		$message->addPart($html, 'text/html');
+				->addHeader('X-Component-Object', 'projects_watch_email')
+				->addPart($plain, 'text/plain')
+				->addPart($html, 'text/html');
 
 		// Send mail
 		if (!$message->send())
 		{
 			$this->setError('Failed to mail %s', $email);
-
 			return false;
 		}
 
 		return true;
 	}
-}
\ No newline at end of file
+}
